==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/ts/Line_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Line</name>
    <message>
        <location filename="../Line.js" line="+81"/>
        <source>Line Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Linie&quot;
Pokaż menu &quot;Łamane&quot;</translatorcomment>
        <translation type="unfinished">Narzędzia linii</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show line tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Linie&quot;</translatorcomment>
        <translation type="unfinished">Pokaż menu &quot;Linie&quot;</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Line</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Linia
&amp;Liniowy</translatorcomment>
        <translation type="unfinished">&amp;Linia</translation>
    </message>
    <message>
        <location filename="../Line.ui" line="+17"/>
        <source>Same Entity Type as Original</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Line Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Infinite Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Ray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/ts/Line_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Line</name>
    <message>
        <location filename="../Line.js" line="+81"/>
        <source>Line Tools</source>
        <translatorcomment>--google--
Pokaż menu &quot;Linie&quot;
Pokaż menu &quot;Łamane&quot;</translatorcomment>
        <translation>Narzędzia linii</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show line tools</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż menu &quot;Linie&quot;</translatorcomment>
        <translation>Wyświetla narzędzia linii</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Line</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Linia
&amp;Liniowy</translatorcomment>
        <translation>&amp;Linia</translation>
    </message>
    <message>
        <location filename="../Line.ui" line="+17"/>
        <source>Same Entity Type as Original</source>
        <translation>Ten sam obiekt co pierwotny</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Line Segment</source>
        <translation>Odcinek</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Infinite Line</source>
        <translation>Prosta</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Ray</source>
        <translation>Półprosta</translation>
    </message>
</context>
</TS>
